/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.PathDiscovery
{
    /// <summary>
    /// Defines an interface with the functionality to match a bread crumb node. The instance of this class is used to
    /// decide the position of the bread crumb node in the whole web site structure. The matching may be done by the
    /// title and/or the URL of the node.
    /// </summary>
    /// <remarks>
    /// The concrete implementation must override <c>Equals</c> and <c>GetHashCode</c> methods to provide support of
    /// <c>Hashtable</c>.
    /// </remarks>
    /// <author>Pops</author>
    /// <author>TCSDEVELOPER</author>
    /// <version>2.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    public interface INodeMatcher
    {
        /// <summary>
        /// Gets a flag indicating whether the given node matches the criteria defined by this node matcher.
        /// </summary>
        /// <param name="node">The bread crumb node to be matched.</param>
        /// <returns><c>true</c> if <c>node</c> matches the criteria; <c>false</c> otherwise.</returns>
        /// <exception cref="ArgumentNullException">The URL of <c>node</c> is <c>null</c>.</exception>
        bool Matches(BreadCrumbNode node);

        /// <summary>
        /// Gets the default title of the node matcher.
        /// </summary>
        /// <remarks>
        /// The default title of the node matcher. It is used when the matched node title is not available.
        /// </remarks>
        /// <value>The default title of the node matcher.</value>
        string Title
        {
            get;
        }

        /// <summary>
        /// Gets the default URL of the node matcher.
        /// </summary>
        /// <remarks>
        /// The default URL of the node matcher. It is used when the matched node URL is not available.
        /// </remarks>
        /// <value>The default URL of the node matcher.</value>
        string Url
        {
            get;
        }
    }
}

