/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using NUnit.Framework;
using NUnit.Extensions.Asp;
using NUnit.Extensions.Asp.AspTester;

namespace TopCoder.Web.UI.WebControl.BreadCrumb
{
    /// <summary>
    /// Tests the functionality and error cases of <c>BreadCrumbTrailControl</c> class. The test cases in this class
    /// uses NUnitAsp. The actual test cases are written in the ASP.NET page.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>2.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public class BreadCrumbTrailControlWebTestCase : WebFormTestCase
    {
        /// <summary>
        /// Tests accuracy of <c>RenderContents(HtmlTextWriter)</c> when an exception is thrown before writing the path.
        /// The error disposition is SilentlyIgnore, so the error is ignored. There should be nothing rendered. This is
        /// verified by the ASP.NET test page via NUnitAsp.
        /// </summary>
        [Test]
        public void TestRenderContentsHtmlTextWriterErrorBeforeWriteIgnoreAccuracy()
        {
            Browser.GetPage("http://localhost/test/BreadCrumbTrailControlWebTest.aspx");

            ButtonTester button = new ButtonTester("RenderContentsHtmlTextWriterErrorBeforeWriteIgnoreAccuracy",
                CurrentWebForm);

            button.Click();
        }

        /// <summary>
        /// Tests accuracy of <c>RenderContents(HtmlTextWriter)</c> when an exception is thrown before writing the path.
        /// The error disposition is RenderException, so the error is rendered. This is verified by the ASP.NET test
        /// page via NUnitAsp.
        /// </summary>
        [Test]
        public void TestRenderContentsHtmlTextWriterErrorBeforeWriteRenderAccuracy()
        {
            Browser.GetPage("http://localhost/test/BreadCrumbTrailControlWebTest.aspx");

            ButtonTester button = new ButtonTester("RenderContentsHtmlTextWriterErrorBeforeWriteRenderAccuracy",
                CurrentWebForm);

            button.Click();
        }

        /// <summary>
        /// Tests <c>RenderContents(HtmlTextWriter)</c> when an exception is thrown before writing the path. The error
        /// disposition is ThrowException, so the error is thrown. Expect BreadCrumbException. This is verified by the
        /// ASP.NET test page via NUnitAsp.
        /// </summary>
        [Test]
        public void TestRenderContentsHtmlTextWriterErrorBeforeWriteThrow()
        {
            Browser.GetPage("http://localhost/test/BreadCrumbTrailControlWebTest.aspx");

            ButtonTester button = new ButtonTester("RenderContentsHtmlTextWriterErrorBeforeWriteThrow",
                CurrentWebForm);

            button.Click();
        }

        /// <summary>
        /// Tests accuracy of <c>RenderContents(HtmlTextWriter)</c> when exceptions occur during writing the path. The
        /// error disposition is SilentlyIgnore, so the errors are ignored. It should render as much as possible. This
        /// is verified by the ASP.NET test page via NUnitAsp.
        /// </summary>
        [Test]
        public void TestRenderContentsHtmlTextWriterWriteErrorIgnoreAccuracy()
        {
            Browser.GetPage("http://localhost/test/BreadCrumbTrailControlWebTest.aspx");

            ButtonTester button = new ButtonTester("RenderContentsHtmlTextWriterWriteErrorIgnoreAccuracy",
                CurrentWebForm);

            button.Click();
        }

        /// <summary>
        /// Tests accuracy of <c>RenderContents(HtmlTextWriter)</c> when exceptions occur during writing the path. The
        /// error disposition is RenderException, so the errors are rendered. It should render as much as possible. This
        /// is verified by the ASP.NET test page via NUnitAsp.
        /// </summary>
        [Test]
        public void TestRenderContentsHtmlTextWriterWriteErrorRenderAccuracy()
        {
            Browser.GetPage("http://localhost/test/BreadCrumbTrailControlWebTest.aspx");

            ButtonTester button = new ButtonTester("RenderContentsHtmlTextWriterWriteErrorRenderAccuracy",
                CurrentWebForm);

            button.Click();
        }

        /// <summary>
        /// Tests <c>RenderContents(HtmlTextWriter)</c> when exceptions occur during writing the path. The error
        /// disposition is ThrowException, so the first error is thrown. Expect BreadCrumbException. This is verified by
        /// the ASP.NET test page via NUnitAsp.
        /// </summary>
        [Test]
        public void TestRenderContentsHtmlTextWriterWriteErrorThrow()
        {
            Browser.GetPage("http://localhost/test/BreadCrumbTrailControlWebTest.aspx");

            ButtonTester button = new ButtonTester("RenderContentsHtmlTextWriterWriteErrorThrow",
                CurrentWebForm);

            button.Click();
        }

        /// <summary>
        /// Tests accuracy of <c>RenderContents(HtmlTextWriter)</c> when there is no overridden path, and all keys are
        /// not specified. It should use default keys to create instances. The path is discovered automatically. This is
        /// verified by comparing the output to a reference output. This is verified by the ASP.NET test page via
        /// NUnitAsp.
        /// </summary>
        [Test]
        public void TestRenderContentsHtmlTextWriterNoOverrideNoKeyAccuracy()
        {
            Browser.GetPage("http://localhost/test/BreadCrumbTrailControlWebTest.aspx");

            ButtonTester button = new ButtonTester("RenderContentsHtmlTextWriterNoOverrideNoKeyAccuracy",
                CurrentWebForm);

            button.Click();
        }

        /// <summary>
        /// Tests accuracy of <c>RenderContents(HtmlTextWriter)</c> when there is no overridden path, and all keys are
        /// specified. It should use the specified keys to create instances. The path is discovered automatically. This
        /// is verified by comparing the output to a reference output. This is verified by the ASP.NET test page via
        /// NUnitAsp.
        /// </summary>
        [Test]
        public void TestRenderContentsHtmlTextWriterNoOverrideAllKeysAccuracy()
        {
            Browser.GetPage("http://localhost/test/BreadCrumbTrailControlWebTest.aspx");

            ButtonTester button = new ButtonTester("RenderContentsHtmlTextWriterNoOverrideAllKeysAccuracy",
                CurrentWebForm);

            button.Click();
        }

        /// <summary>
        /// Tests accuracy of <c>RenderContents(HtmlTextWriter)</c> when there is an overridden path. The path should be
        /// rendered directly. This is verified by comparing the output to a reference output. This is verified by the
        /// ASP.NET test page via NUnitAsp.
        /// </summary>
        [Test]
        public void TestRenderContentsHtmlTextWriterOverrideAccuracy()
        {
            Browser.GetPage("http://localhost/test/BreadCrumbTrailControlWebTest.aspx");

            ButtonTester button = new ButtonTester("RenderContentsHtmlTextWriterOverrideAccuracy",
                CurrentWebForm);

            button.Click();
        }

        /// <summary>
        /// Tests accuracy of <c>RenderContents(HtmlTextWriter)</c> when there is no path for the current node. It
        /// should render nothing. This is verified by the ASP.NET test page via NUnitAsp.
        /// </summary>
        [Test]
        public void TestRenderContentsHtmlTextWriterNoPathAccuracy()
        {
            Browser.GetPage("http://localhost/test/BreadCrumbTrailControlWebTest.aspx");

            ButtonTester button = new ButtonTester("RenderContentsHtmlTextWriterNoPathAccuracy",
                CurrentWebForm);

            button.Click();
        }
    }
}

