/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using NUnit.Framework;

namespace TopCoder.Web.UI.WebControl.BreadCrumb
{
    /// <summary>
    /// Tests the functionality of customized exceptions. The constructor used to deserialize the exception is not
    /// tested, since it is mainly for the system use.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>2.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public class ExceptionTestCase
    {
        /// <summary>
        /// Represents a detail error message.
        /// </summary>
        private const string DETAIL_MESSAGE = "A detail message";

        /// <summary>
        /// Represents a original cause of the error.
        /// </summary>
        private static readonly Exception CAUSE = new Exception();

        /// <summary>
        /// Tests accuracy of <c>BreadCrumbException(string)</c>. The detail error message should be retrieved as set
        /// in the argument.
        /// </summary>
        [Test]
        public void TestBreadCrumbExceptionStringAccuracy()
        {
            BreadCrumbException exception = new BreadCrumbException(DETAIL_MESSAGE);

            Assert.AreEqual(DETAIL_MESSAGE, exception.Message, "The detail message should be the same as in argument.");
        }

        /// <summary>
        /// Tests accuracy of <c>BreadCrumbException(string, Exception)</c>. The detail error message should be
        /// retrieved as set in the argument. The original cause of the error should be retrieved as set in the
        /// argument.
        /// </summary>
        [Test]
        public void TestBreadCrumbExceptionStringExceptionAccuracy()
        {
            BreadCrumbException exception = new BreadCrumbException(DETAIL_MESSAGE, CAUSE);

            Assert.AreEqual(DETAIL_MESSAGE, exception.Message, "The detail message should be the same as in argument.");
            Assert.AreEqual(CAUSE, exception.InnerException, "The cause should be the same as in argument.");
        }

        /// <summary>
        /// Tests accuracy of <c>BreadCrumbException()</c>. A new instance of the exception should be created.
        /// </summary>
        [Test]
        public void TestBreadCrumbExceptionAccuracy()
        {
            Assert.IsNotNull(new BreadCrumbException(), "The exception should be created.");
        }
    }
}

