/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;
using NUnit.Framework;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.PathDiscovery
{
    /// <summary>
    /// Tests the functionality and error cases of <c>AbstractNodeMatcher</c> class. Since this class is an abstract
    /// class, its concrete implementation <c>MockNodeMatcher</c> is used in the tests. Since this class is immutable,
    /// the property getters are tested together with the constructor.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>2.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    [TestFixture]
    public class AbstractNodeMatcherTestCase
    {
        /// <summary>
        /// Tests <c>AbstractNodeMatcher(string, string)</c> when the title is <c>null</c>. Expect
        /// ArgumentNullException.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestAbstractNodeMatcherStringStringTitleNull()
        {
            new MockNodeMatcher(null, "url");
        }

        /// <summary>
        /// Tests <c>AbstractNodeMatcher(string, string)</c> when the title is empty string. Expect
        /// ArgumentException.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentException))]
        public void TestAbstractNodeMatcherStringStringTitleEmpty()
        {
            new MockNodeMatcher("   ", "url");
        }

        /// <summary>
        /// Tests <c>AbstractNodeMatcher(string, string)</c> when the URL is <c>null</c>. Expect
        /// ArgumentNullException.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentNullException))]
        public void TestAbstractNodeMatcherStringStringURLNull()
        {
            new MockNodeMatcher("title", null);
        }

        /// <summary>
        /// Tests <c>AbstractNodeMatcher(string, string)</c> when the URL is empty string. Expect
        /// ArgumentException.
        /// </summary>
        [Test, ExpectedException(typeof(ArgumentException))]
        public void TestAbstractNodeMatcherStringStringURLEmpty()
        {
            new MockNodeMatcher("title", "   ");
        }

        /// <summary>
        /// Tests accuracy of <c>AbstractNodeMatcher(string, string)</c>. The title and the URL of the node matcher
        /// should be set as given. These are verified by the property getters. This is also a test case for the
        /// property getters.
        /// </summary>
        [Test]
        public void TestAbstractNodeMatcherStringStringAccuracy()
        {
            INodeMatcher matcher = new MockNodeMatcher("title", "url");

            // Verify
            Assert.AreEqual("title", matcher.Title, "The title should be set as 'title'.");
            Assert.AreEqual("url", matcher.Url, "The URL should be set as 'url'.");
        }
    }
}

