/*
 * Copyright (c) 2006, TopCoder, Inc. All rights reserved.
 */
using System;

namespace TopCoder.Web.UI.WebControl.BreadCrumb.PathDiscovery
{
    /// <summary>
    /// Defines a mock concrete implementation of <c>INodeMatcher</c> interface by extending the
    /// <c>AbstractNodeMatcher</c> class. It is used to test the <c>AbstractNodeMatcher</c> class.
    /// </summary>
    /// <author>TCSDEVELOPER</author>
    /// <version>2.0</version>
    /// <copyright>Copyright (c) 2006, TopCoder, Inc. All rights reserved.</copyright>
    public class MockNodeMatcher : AbstractNodeMatcher
    {
        /// <summary>
        /// Creates a new instance of <c>MockNodeMatcher</c> class. The default title and the default URL are given.
        /// </summary>
        /// <param name="title">The default title of the node matcher.</param>
        /// <param name="url">The default URL of the node matcher.</param>
        /// <exception cref="ArgumentNullException"><c>title</c> or <c>url</c> is <c>null</c>.</exception>
        /// <exception cref="ArgumentException"><c>title</c> or <c>url</c> is empty string.</exception>
        public MockNodeMatcher(string title, string url)
            : base(title, url)
        {
        }

        /// <summary>
        /// Gets a flag indicating whether the given node matches the criteria defined by this node matcher.
        /// </summary>
        /// <remarks>
        /// It always returns <c>false</c>.
        /// </remarks>
        /// <param name="node">The bread crumb node to be matched.</param>
        /// <returns><c>false</c>.</returns>
        public override bool Matches(BreadCrumbNode node)
        {
            return false;
        }
    }
}

