<%@ Page Language="C#" Debug="true" %>
<%@ Import Namespace="TopCoder.Web.UI.WebControl.BreadCrumb" %>
<%@ Import Namespace="TopCoder.Web.UI.WebControl.BreadCrumb.PathDiscovery" %>
<%@ Import Namespace="TopCoder.Web.UI.WebControl.BreadCrumb.PathDiscovery.NodeMatcher" %>
<%@ Import Namespace="NUnit.Framework" %>

<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Transitional//EN">

<script runat="server">
    /// <summary>
    /// Represents the <c>XmlPathDiscovery</c> instance used in tests.
    /// </summary>
    private IPathDiscovery pathDiscovery;

    /// <summary>
    /// Tests <c>GetPath(BreadCrumbNode, Page)</c> when the reversed site map is invalid. Expect BreadCrumbException.
    /// </summary>
    /// <param name="sender">The instance which causes this event.</param>
    /// <param name="e">The event parameter.</param>
    protected void TestGetPathBreadCrumbNodePageSiteMapInvalid(object sender, EventArgs e)
    {
        BreadCrumbNode node = new BreadCrumbNode("title", "/normal.aspx");

        // Set the invalid site map
        IDictionary map = new Hashtable();
        
        Page.Session[XmlPathDiscovery.CURRENT_SITEMAP] = new Hashtable();
        Page.Session[XmlPathDiscovery.CURRENT_REVERSE_SITEMAP] = map;

        map.Add(new RegexNodeMatcher("normal", "/normal.aspx", "/normal.*"), new object());

        try
        {
            pathDiscovery.GetPath(node, Page);
            Assert.Fail("The reversed site map is invalid, should throw BreadCrumbException.");
        }
        catch (BreadCrumbException)
        {
            // good
        }
    }

    /// <summary>
    /// Tests <c>GetPath(BreadCrumbNode, Page)</c> when retrieveing the site map fails. Expect BreadCrumbException.
    /// </summary>
    /// <param name="sender">The instance which causes this event.</param>
    /// <param name="e">The event parameter.</param>
    protected void TestGetPathBreadCrumbNodePageGetSiteMapFail(object sender, EventArgs e)
    {
        BreadCrumbNode node = new BreadCrumbNode("title", "/normal.aspx");

        // Create an invalid site map discovery
        pathDiscovery = new XmlPathDiscovery("invalid.xml");

        try
        {
            pathDiscovery.GetPath(node, Page);
            Assert.Fail("Retrieving site map fails, should throw BreadCrumbException.");
        }
        catch (BreadCrumbException)
        {
            // good
        }
    }

    /// <summary>
    /// Asserts the two given paths are the same. The titles and URLs of the bread crumb nodes must be the same.
    /// </summary>
    /// <param name="expected">The expected path to be compared with.</param>
    /// <param name="actual">The actual path to be compared with.</param>
    /// <param name="message">The error message when the assertion fails.</param>
    /// <exception cref="AssertionException">The actual path is not the same as the expected path.</exception>
    private static void AreEqual(BreadCrumbNode[] expected, BreadCrumbNode[] actual, string message)
    {
        // Verify the counts of redirection
        Assert.AreEqual(expected.Length, actual.Length, message);

        // Verify every item
        for (int i = 0; i < expected.Length; ++i)
        {
            Assert.AreEqual(expected[i].Title, actual[i].Title, message);
            Assert.AreEqual(expected[i].Url, actual[i].Url, message);
        }
    }

    /// <summary>
    /// Tests accuracy of <c>GetPath(BreadCrumbNode, Page)</c> when two matchers matches the given bread crumb node.
    /// The shortest path should be selected. Since the title of the node is <c>null</c>, the title in the matcher is
    /// used.
    /// </summary>
    /// <param name="sender">The instance which causes this event.</param>
    /// <param name="e">The event parameter.</param>
    protected void TestGetPathBreadCrumbNodePageTwoMatchedAccuracy(object sender, EventArgs e)
    {
        BreadCrumbNode node = new BreadCrumbNode(null, "/match3.aspx");

        // Get the path
        BreadCrumbNode[] path = pathDiscovery.GetPath(node, Page);

        // Build the expected array
        BreadCrumbNode[] expected = new BreadCrumbNode[] {
            new BreadCrumbNode("main2", "/main2.aspx"),
            new BreadCrumbNode("match2", "/match3.aspx")
        };
        
        // Verify
        AreEqual(expected, path, "The path should be the shortest one.");
    }

    /// <summary>
    /// Tests accuracy of <c>GetPath(BreadCrumbNode, Page)</c> when one matched matcher has multiple roots. The
    /// shortest path should be selected. The title of the given bread crumb node should be used.
    /// </summary>
    /// <param name="sender">The instance which causes this event.</param>
    /// <param name="e">The event parameter.</param>
    protected void TestGetPathBreadCrumbNodePageMultipleRootsAccuracy(object sender, EventArgs e)
    {
        BreadCrumbNode node = new BreadCrumbNode("customized", "/dup.aspx");

        // Get the path
        BreadCrumbNode[] path = pathDiscovery.GetPath(node, Page);

        // Build the expected array
        BreadCrumbNode[] expected = new BreadCrumbNode[] {
            new BreadCrumbNode("main2", "/main2.aspx"),
            new BreadCrumbNode("customized", "/dup.aspx")
        };

        // Verify
        AreEqual(expected, path, "The path should be the shortest one.");
    }

    /// <summary>
    /// Tests accuracy of <c>GetPath(BreadCrumbNode, Page)</c> when no matched matcher has been found. It should
    /// return <c>null</c>.
    /// </summary>
    /// <param name="sender">The instance which causes this event.</param>
    /// <param name="e">The event parameter.</param>
    protected void TestGetPathBreadCrumbNodePageNoMatchAccuracy(object sender, EventArgs e)
    {
        BreadCrumbNode node = new BreadCrumbNode("notfound", "/nomatch.aspx");

        // Get the path
        Assert.IsNull(pathDiscovery.GetPath(node, Page), "The path should not be found.");
    }

    /// <summary>
    /// Tests accuracy of <c>GetPath(BreadCrumbNode, Page)</c> when looped matcher matches the node. It should
    /// return <c>null</c>, since there is no path to the root.
    /// </summary>
    /// <param name="sender">The instance which causes this event.</param>
    /// <param name="e">The event parameter.</param>
    protected void TestGetPathBreadCrumbNodePageLoopAccuracy(object sender, EventArgs e)
    {
        BreadCrumbNode node = new BreadCrumbNode("nopath", "/nopath.aspx");

        // Get the path
        Assert.IsNull(pathDiscovery.GetPath(node, Page), "The path should not be found.");
    }

    /// <summary>
    /// Tests accuracy of <c>GetPath(BreadCrumbNode, Page)</c> when one normal matcher matches the node. It should
    /// return the shortest path.
    /// </summary>
    /// <param name="sender">The instance which causes this event.</param>
    /// <param name="e">The event parameter.</param>
    protected void TestGetPathBreadCrumbNodePageNormalAccuracy(object sender, EventArgs e)
    {
        BreadCrumbNode node = new BreadCrumbNode("normal", "/normal.aspx");

        // Get the path
        BreadCrumbNode[] path = pathDiscovery.GetPath(node, Page);

        // Build the expected array
        BreadCrumbNode[] expected = new BreadCrumbNode[] {
            new BreadCrumbNode("main", "/main.aspx"),
            new BreadCrumbNode("loop", "/loop.aspx"),
            new BreadCrumbNode("inner", "/inner.aspx"),
            new BreadCrumbNode("match1", "/match1.aspx"),
            new BreadCrumbNode("normal", "/normal.aspx")
        };

        // Verify
        AreEqual(expected, path, "The path should be the shortest one.");
    }

    /// <summary>
    /// Sets up the test environment when the page is loaded. The test instance is created. The session is cleared.
    /// </summary>
    /// <param name="e">The event parameter.</param>
    protected override void OnLoad(EventArgs e)
    {
        base.OnLoad(e);

        Page.Session.Clear();
        pathDiscovery = new XmlPathDiscovery(Page.MapPath("Valid.xml"));
    }

    /// <summary>
    /// Cleans up the test environment when the page is unloaded. The test instance is disposed. The session is cleared.
    /// </summary>
    /// <param name="e">The event parameter.</param>
    protected override void OnUnload(EventArgs e)
    {
        pathDiscovery = null;
        Page.Session.Clear();

        base.OnUnload(e);
    }
</script>

<html xmlns="http://www.w3.org/1999/xhtml" >
<head runat="server">
    <title>XmlPathDiscoveryTest</title>
</head>
<body runat="server">
    <form id="form1" runat="server">
    <div>
        <asp:Button ID="GetPathBreadCrumbNodePageSiteMapInvalid" runat="server" OnClick="TestGetPathBreadCrumbNodePageSiteMapInvalid" Text="GetPathBreadCrumbNodePageSiteMapInvalid" />
        <asp:Button ID="GetPathBreadCrumbNodePageTwoMatchedAccuracy" runat="server" OnClick="TestGetPathBreadCrumbNodePageTwoMatchedAccuracy" Text="GetPathBreadCrumbNodePageTwoMatchedAccuracy" />
        <asp:Button ID="GetPathBreadCrumbNodePageMultipleRootsAccuracy" runat="server" OnClick="TestGetPathBreadCrumbNodePageMultipleRootsAccuracy" Text="GetPathBreadCrumbNodePageMultipleRootsAccuracy" />
        <asp:Button ID="GetPathBreadCrumbNodePageNoMatchAccuracy" runat="server" OnClick="TestGetPathBreadCrumbNodePageNoMatchAccuracy" Text="GetPathBreadCrumbNodePageNoMatchAccuracy" />
        <asp:Button ID="GetPathBreadCrumbNodePageLoopAccuracy" runat="server" OnClick="TestGetPathBreadCrumbNodePageLoopAccuracy" Text="GetPathBreadCrumbNodePageLoopAccuracy" />
        <asp:Button ID="GetPathBreadCrumbNodePageNormalAccuracy" runat="server" OnClick="TestGetPathBreadCrumbNodePageNormalAccuracy" Text="GetPathBreadCrumbNodePageNormalAccuracy" />
        <asp:Button ID="GetPathBreadCrumbNodePageGetSiteMapFail" runat="server" OnClick="TestGetPathBreadCrumbNodePageGetSiteMapFail" Text="GetPathBreadCrumbNodePageGetSiteMapFail" />
    </div>
    </form>
</body>
</html>
